==> flopswap_0.0.5.tar.gz: flopswap-0.0.5/script/swapswitchejectsd.sh <==
#!/bin/sh

##Made by sixwheeledbeast, Estel, Malkavian, peterleinchen and vi_

#Go root if not
if [ `id -u` != 0 ] ; then
              exec | sudo gainroot <<EOF
exec sh $0 $*
EOF
              exit $?
fi

# Setup swap names for script

## Swap 0 - Backup internal swap location
swap0=/dev/mmcblk0p3

## Swap 1 - First Main Swap Location
swap1=/dev/mmcblk1p2

## Swap 2 - Second Main Swap Location
swap2=/dev/mmcblk1p3

# Setup notification banner
banner(){
o=org
f=freedesktop
n=Notifications
run-standalone.sh dbus-send --type=method_call \
--dest=$o.$f.$n /$o/$f/$n $o.$f.$n.SystemNoteInfoprint string:"$1"
}

# Get and Print Current Swap Pre
preswap=`cat /proc/swaps | awk '/dev/ {print $1}'`
banner "$preswap"
sleep 5

#Logic
if [ "$preswap" = "$swap1" ];
then
   nice -20 swapon $swap0
   nice -20 swapoff $swap1
sleep 3
elif [ "$preswap" = "$swap2" ];
then
   nice -20 swapon $swap0
   nice -20 swapoff $swap2
sleep 3
elif [ "$preswap" = "$swap0" ];
  then
sleep 1
   banner "Safe to remove back cover"
else
  banner "Swap Switch Failed"
sleep 2
 banner "DO NOT REMOVE BACK COVER - Please check swaps manually via terminal"
fi
###########
#fi
#sleep 2
##Get current swap from /proc/swaps
#disk=$(cat /proc/swaps | awk '/dev/ {print $1}' | cut -d "/" -f 3)
##Get blocks used since boot from /proc/diskstats
#ublocks=$(awk '{if ($3=="'"$disk"'") print $10}' /proc/diskstats)
##echo $ublocks ublocks
##Multiply blocks by 512 to get used bytes
#ubytes=$(($ublocks*512))
##Calculate used bytes into Kb, Mb and Gb
#echo $ubytes ubytes
#ukbytes=$(($ubytes/1024))
#umbytes=$(($ubytes/1024/1024))
#ugbytes=$(($ubytes/1024/1024/1024))
#echo $ukbytes ukbytes, $umbytes umbytes, $ugbytes ugbytes
#echo "$umbytes" > /tmp/flopswaplast && exit 1
############

==> flopswap_0.0.6.tar.gz: flopswap-0.0.6/script/swapswitchejectsd.sh <==
#!/bin/sh

##Made by sixwheeledbeast, Estel, Malkavian, peterleinchen and vi_

##Go root if not (depends rootsh)
#if [ `id -u` != 0 ] ; then
#              exec | sudo gainroot <<EOF
#exec sh $0 $*
#EOF
#              exit $?
#fi

# Setup swap names for script

## Swap 0 - Backup internal swap location
swap0=/dev/mmcblk0p3

## Swap 1 - First Main Swap Location
swap1=/dev/mmcblk1p2

## Swap 2 - Second Main Swap Location
swap2=/dev/mmcblk1p3

## Nice
nice="/bin/busybox nice -20"

## Swap Command
xswapon="/bin/busybox swapon"
xswapoff="/bin/busybox swapoff"

# Setup notification banner
banner(){
o=org
f=freedesktop
n=Notifications
run-standalone.sh dbus-send --type=method_call \
--dest=$o.$f.$n /$o/$f/$n $o.$f.$n.SystemNoteInfoprint string:"$1"
}

# Get and Print Current Swap Pre
preswap=`cat /proc/swaps | awk '/dev/ {print $1}'`
banner "$preswap"
sleep 5

#Logic
if [ "$preswap" = "$swap1" ];
then
   $nice $xswapon $swap0
   $nice $xswapoff $swap1
sleep 3
elif [ "$preswap" = "$swap2" ];
then
   $nice $xswapon $swap0
   $nice $xswapoff $swap2
sleep 3
elif [ "$preswap" = "$swap0" ];
  then
sleep 1
   banner "Safe to remove back cover"
else
  banner "Swap Switch Failed"
sleep 2
 banner "DO NOT REMOVE BACK COVER - Please check swaps manually via terminal"
fi
###########
#fi
#sleep 2
##Get current swap from /proc/swaps
#disk=$(cat /proc/swaps | awk '/dev/ {print $1}' | cut -d "/" -f 3)
##Get blocks used since boot from /proc/diskstats
#ublocks=$(awk '{if ($3=="'"$disk"'") print $10}' /proc/diskstats)
##echo $ublocks ublocks
##Multiply blocks by 512 to get used bytes
#ubytes=$(($ublocks*512))
##Calculate used bytes into Kb, Mb and Gb
#echo $ubytes ubytes
#ukbytes=$(($ubytes/1024))
#umbytes=$(($ubytes/1024/1024))
#ugbytes=$(($ubytes/1024/1024/1024))
#echo $ukbytes ukbytes, $umbytes umbytes, $ugbytes ugbytes
#echo "$umbytes" > /tmp/flopswaplast && exit 1
############
